@@ -2,6 +2,8 @@ package Test::Smoke::LogMixin;
 use warnings;
 use strict;
 
+our $VERSION = '0.001';
+
 use Exporter 'import';
 our @EXPORT = qw/verbosity log_warn log_info log_debug/;
 
@@ -147,7 +149,9 @@ sub _log_message {
     (my $fmt = shift) =~ s/\n*\z//;
 
     my $stamp = $USE_TIMESTAMP
-        ? POSIX::strftime("[%Y-%m-%d %H:%M:%S%z] ", localtime)
+        ? $^O eq 'MSWin32'
+            ? POSIX::strftime("[%Y-%m-%d %H:%M:%SZ] ", gmtime)
+            : POSIX::strftime("[%Y-%m-%d %H:%M:%S%z] ", localtime)
         : "";
 
     # use the $stamp for every line.
